@@ -397,10 +397,14 @@ class FramedImage(FramedArray):
         # if not resampling, just change the image vox2world matrix and return
         if not resample and affine is not None:
             affine = cast_affine(affine)
-            if affine.source is None and affine.target is None or affine.space is None:
-                raise ValueError('affine must contain source, target, and coordinate space info to transform image header')
             transformed = self.copy()
-            transformed.geom.vox2world = affine.convert(space='world', source=self) @ transformed.geom.vox2world
+            # if affine is missing geometry info, let's just assume it's in world space
+            if affine.source is not None and affine.target is not None:
+                affine = affine.convert(space='world', source=self)
+            elif affine.space is not None and affine.space != 'world':
+                raise ValueError('affine must contain source and target info if not in world space')
+            # apply forward transform to the header
+            transformed.geom.vox2world = affine @ transformed.geom.vox2world
             return transformed
 
         # sanity check and preprocess the affine if resampling
@@ -504,10 +508,9 @@ class FramedImage(FramedArray):
             Reshaped image.
         """
         if self.basedim == 2:
-            raise NotImplementedError('reshape() is not yet implemented for 2D data, contact andrew if you need this')
-        if self.nframes > 1:
-            # TODO
-            raise NotImplementedError
+            raise NotImplementedError('reshape is not yet implemented for 2D data, contact andrew if you need this')
+
+        shape = shape[:self.basedim]
 
         if np.array_equal(self.baseshape, shape):
             return self.copy() if copy else self
@@ -518,9 +521,10 @@ class FramedImage(FramedArray):
 
         c_low = np.clip(low, 0, None)
         c_high = np.clip(high, 0, None)
-        conformed_data = np.pad(self.data.squeeze(), list(zip(c_low, c_high)), mode='constant')
+        padding = list(zip(np.append(c_low, 0), np.append(c_high, 0)))
+        conformed_data = np.pad(self.framed_data, padding, mode='constant')
 
-        # note: low and high are intentionally swapped here
+        # low and high are intentionally swapped here
         c_low = np.clip(-high, 0, None)
         c_high = conformed_data.shape[:3] - np.clip(-low, 0, None)
         cropping = tuple([slice(a, b) for a, b in zip(c_low, c_high)])
@@ -628,3 +632,44 @@ def cast_image(obj, allow_none=True, copy=False):
         pass
 
     raise ValueError('cannot convert type %s to image' % type(obj).__name__)
+
+
+def cast_slice(obj, allow_none=True, copy=False):
+    """
+    Cast object to `Slice` type.
+
+    Parameters
+    ----------
+    obj : any
+        Object to cast.
+    allow_none : bool
+        Allow for `None` to be successfully passed and returned by cast.
+    copy : bool
+        Return copy if object is already the correct type.
+
+    Returns
+    -------
+    FramedImage or None
+        Casted image.
+    """
+    if obj is None and allow_none:
+        return obj
+
+    if isinstance(obj, Slice):
+        return obj.copy() if copy else obj
+
+    if getattr(obj, '__array__', None) is not None:
+        return Slice(np.array(obj))
+
+    # as a final test, check if the input is possibly a nibabel image
+    # we don't want nibabel to be required though, so ignore import errors
+    try:
+        import nibabel as nib
+        if isinstance(obj, nib.spatialimages.SpatialImage):
+            data = obj.get_data().copy()
+            geometry = ImageGeometry(data.shape[:3], vox2world=obj.affine)
+            return Slice(data, geometry=geometry)
+    except ImportError:
+        pass
+
+    raise ValueError('cannot convert type %s to image' % type(obj).__name__)
